@@ -108,9 +108,9 @@ lmrob.M.S <- function(x, y, control, mf, split) {
     c.chi <- lmrob.conv.cc(control$psi, control$tuning.chi)
 
     z <- .C(R_lmrob_M_S,
-            X1=x1,
-            X2=x2,
-            y=y,
+	    x1,
+	    x2,
+	    y,
             res=double(length(y)),
             n=length(y),
             p1=ncol(x1),
@@ -120,11 +120,12 @@ lmrob.M.S <- function(x, y, control, mf, split) {
             b1=double(ncol(x1)),
             b2=double(ncol(x2)),
             tuning_chi=as.double(c.chi),
-            ipsi=as.integer(lmrob.psi2ipsi(control$psi)),
+	    ipsi = as.integer(lmrob.psi2ipsi(control$psi)),
             bb=as.double(control$bb),
             K_m_s=as.integer(control$k.m_s),
             max_k=as.integer(control$k.max),
             rel_tol=as.double(control$rel.tol),
+	    inv_tol=as.double(control$solve.tol),
             converged=logical(1),
             trace_lev=as.integer(control$trace.lev),
             orthogonalize=TRUE,
